@@ -20,7 +20,7 @@ var bind = function bind(obj) {
 Function.prototype.bind = Function.prototype.bind || bind ;
 
 
-require([
+requirejs([
     'jquery',
     'contents',
     'base/js/namespace',
@@ -44,7 +44,8 @@ require([
     'codemirror/lib/codemirror',
     'notebook/js/about',
     'notebook/js/searchandreplace',
-    'notebook/js/clipboard'
+    'notebook/js/clipboard',
+    'bidi/bidi'
 ], function(
     $,
     contents_service,
@@ -69,7 +70,8 @@ require([
     CodeMirror,
     about,
     searchandreplace,
-    clipboard
+    clipboard,
+    bidi
     ) {
     "use strict";
 
@@ -78,6 +80,7 @@ require([
     
     try{
         requirejs(['custom/custom'], function() {});
+        bidi.loadLocale();
     } catch(err) {
         console.log("Error processing custom.js. Logging and continuing");
         console.warn(err);
